@@ -4,14 +4,13 @@ import tempfile
 import subprocess
 import sys
 
+from . import test_dir
 
-sequana_path = easydev.get_package_location('sequana_demultiplex')
-sharedir = os.sep.join([sequana_path , "sequana_pipelines", 'demultiplex', 'data'])
-samplesheet = os.sep.join([sharedir, "SampleSheet.csv"]) 
-
+samplesheet = f"{test_dir}/data/SampleSheet.csv"
+bcldir = f"{test_dir}/data/bcl"
 
 def test_help():
-    cmd = """sequana_pipelines_demultiplex --help"""
+    cmd = """sequana_demultiplex --help"""
     subprocess.call(cmd.split())
 
 
@@ -20,9 +19,9 @@ def test_standalone_subprocess(tmp_path):
     directory.mkdir()
 
     with tempfile.TemporaryDirectory() as directory:
-        cmd = """sequana_pipelines_demultiplex --bcl-directory {} """
+        cmd = """sequana_demultiplex --bcl-directory {} """
         cmd += """--run-mode local --working-directory {} --force --sample-sheet {} --merging-strategy none"""
-        cmd = cmd.format(sharedir +"/bcl", directory, samplesheet)
+        cmd = cmd.format(bcldir, directory, samplesheet)
         subprocess.call(cmd.split())
 
 
@@ -30,7 +29,7 @@ def test_standalone_script(tmp_path):
     directory = tmp_path / "test"
     directory.mkdir()
     import sequana_pipelines.demultiplex.main as m
-    sys.argv = ["test", "--bcl-directory", sharedir+"/bcl", "--merging-strategy", "merge",
+    sys.argv = ["test", "--bcl-directory", bcldir, "--merging-strategy", "merge",
           "--working-directory", str(directory), "--force", "--sample-sheet", samplesheet]
     m.main()
 
@@ -40,8 +39,8 @@ def test_standalone_baddies(tmp_path):
     directory.mkdir()
 
     with tempfile.TemporaryDirectory() as directory:
-        cmd = """sequana_pipelines_demultiplex --bcl-directory {} """
+        cmd = """sequana_demultiplex --bcl-directory {} """
         cmd += """--run-mode local --working-directory {} --force --sample-sheet {} --merging-strategy none"""
-        cmd = cmd.format(sharedir + "/bcl", directory, "wrong")
+        cmd = cmd.format(bcldir, directory, "wrong")
         subprocess.call(cmd.split())
 
